Fuzzy Match Species within Genus
Source:R/fuzzy_match_species_within_genus.R
wcvp_fuzzy_match_species_within_genus.RdTries to fuzzy match the species epithet within a matched genus against 'WCVP' (using the optional wcvpdata checklist by default when available).
Arguments
- df
tibblecontaining the species binomial split into the columnsOrig.GenusandOrig.Species.- target_df
Optional custom target table. If
NULL, the optionalwcvpdatachecklist is used when available; otherwise pass a backbone explicitly.- max_dist
Maximum edit distance used for fuzzy species matching within genus.
- method
String distance method passed to
fozziejoin(for example"osa").